==> openshift-model-miscellaneous-5.12.3-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/NICBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class NICBuilder extends io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICFluentImpl<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NIC,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICBuilder>{
  public NICBuilder() {
    this(false);
  }
  public NICBuilder(java.lang.Boolean validationEnabled) {
    this(new NIC(), validationEnabled);
  }
  public NICBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICFluent<?> fluent) {
    this(fluent, false);
  }
  public NICBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new NIC(), validationEnabled);
  }
  public NICBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NIC instance) {
    this(fluent, instance, false);
  }
  public NICBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICFluent<?> fluent,io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NIC instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withIp(instance.getIp()); 
    fluent.withMac(instance.getMac()); 
    fluent.withModel(instance.getModel()); 
    fluent.withName(instance.getName()); 
    fluent.withPxe(instance.getPxe()); 
    fluent.withSpeedGbps(instance.getSpeedGbps()); 
    fluent.withVlanId(instance.getVlanId()); 
    fluent.withVlans(instance.getVlans()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NICBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NIC instance) {
    this(instance,false);
  }
  public NICBuilder(io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NIC instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withIp(instance.getIp()); 
    this.withMac(instance.getMac()); 
    this.withModel(instance.getModel()); 
    this.withName(instance.getName()); 
    this.withPxe(instance.getPxe()); 
    this.withSpeedGbps(instance.getSpeedGbps()); 
    this.withVlanId(instance.getVlanId()); 
    this.withVlans(instance.getVlans()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NICFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1.NIC build() {
    NIC buildable = new NIC(fluent.getIp(),fluent.getMac(),fluent.getModel(),fluent.getName(),fluent.getPxe(),fluent.getSpeedGbps(),fluent.getVlanId(),fluent.getVlans());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NICBuilder that = (NICBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-miscellaneous-6.6.2-sources.jar: io/fabric8/openshift/api/model/miscellaneous/metal3/v1alpha1/NICBuilder.java <==
package io.fabric8.openshift.api.model.miscellaneous.metal3.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class NICBuilder extends NICFluentImpl<NICBuilder> implements VisitableBuilder<NIC,NICBuilder>{
  public NICBuilder() {
    this(false);
  }
  public NICBuilder(Boolean validationEnabled) {
    this(new NIC(), validationEnabled);
  }
  public NICBuilder(NICFluent<?> fluent) {
    this(fluent, false);
  }
  public NICBuilder(NICFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new NIC(), validationEnabled);
  }
  public NICBuilder(NICFluent<?> fluent,NIC instance) {
    this(fluent, instance, false);
  }
  public NICBuilder(NICFluent<?> fluent,NIC instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withIp(instance.getIp()); 
    fluent.withMac(instance.getMac()); 
    fluent.withModel(instance.getModel()); 
    fluent.withName(instance.getName()); 
    fluent.withPxe(instance.getPxe()); 
    fluent.withSpeedGbps(instance.getSpeedGbps()); 
    fluent.withVlanId(instance.getVlanId()); 
    fluent.withVlans(instance.getVlans()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public NICBuilder(NIC instance) {
    this(instance,false);
  }
  public NICBuilder(NIC instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withIp(instance.getIp()); 
    this.withMac(instance.getMac()); 
    this.withModel(instance.getModel()); 
    this.withName(instance.getName()); 
    this.withPxe(instance.getPxe()); 
    this.withSpeedGbps(instance.getSpeedGbps()); 
    this.withVlanId(instance.getVlanId()); 
    this.withVlans(instance.getVlans()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  NICFluent<?> fluent;
  Boolean validationEnabled;
  public NIC build() {
    NIC buildable = new NIC(fluent.getIp(),fluent.getMac(),fluent.getModel(),fluent.getName(),fluent.getPxe(),fluent.getSpeedGbps(),fluent.getVlanId(),fluent.getVlans());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
